==> driza-unix-0.2.tar.gz: driza-unix-0.2/src/config.py <==
#Fichero de gestión de configuración

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


import pickle
import datos
# Gestion de ficheros de configuracion

# Elementos a configurar:

	#tmpdir: Guarda la ruta del directorio de trabajo
	#rdir:   Guarda la ruta del ejecutable de R
	#vsplash: boolean que dice si aparece la ventana splash o no
	#lfichero: Tipo especial derivado de lista que guarda la lista de ficheros más recientes





class ConfigHandler:
	"""Clase que maneja la config
	ALTERNATIVA:pprint.pprint(dict_configuracion, open(configuracion, 'w'))
	"""
	def __init__(self):
		self.parametros={}
		self.new=False #Variable que almacena si existe previamente la configuración o no
		try:
			self.archivo=open("./drizaconfig","r")
		except: #Archivo nuevo
			self.new=True
			self.archivo=open("./drizaconfig","w")
			pickle.dump(self.__default(),self.archivo)
			self.archivo.close()
			self.archivo=open("./drizaconfig","r")
		self.parametros=pickle.load(self.archivo)
		self.archivo.close()
	def __default(self):
		listado=datos.Listaficheros()
		return {"tmpdir":"/tmp","rdir":"/usr/bin/R","lfichero":listado,"vsplash":True}
	def __getitem__(self,valor):
		return self.parametros[valor]
	def __setitem__(self, clave, valor):
		"""Funcion para establecer la clave de un valor
		"""
		if not clave in self.parametros:
			self.parametros.append(clave)
		self.parametros[clave]=valor
	def save(self):
		self.archivo=open("./drizaconfig","w")
		pickle.dump(self.parametros,self.archivo)
		self.archivo.close()

==> driza-unix-0.3.tar.gz: driza-unix-0.3/src/config.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#Fichero de gestión de configuración

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


import pickle
import datos
# Gestion de ficheros de configuracion

# Elementos a configurar:

	#tmpdir: Guarda la ruta del directorio de trabajo
	#rdir:   Guarda la ruta del ejecutable de R
	#vsplash: boolean que dice si aparece la ventana splash o no
	#lfichero: Lista de ficheros


class ConfigHandler:
	"""Clase que maneja la config
	ALTERNATIVA:pprint.pprint(dict_configuracion, open(configuracion, 'w'))
	"""
	def __init__(self):
		"""Funcion de inicialización del config handler
		El parametro args es un diccionario con los argumentos cedidos por el usuario en la linea de comandos
		"""
		self.parametros={}
		self.new=False #Variable que almacena si existe previamente la configuración o no
		try:
			self.archivo=open("./drizaconfig","r")
		except: #Archivo nuevo
			self.new=True
			self.archivo=open("./drizaconfig","w")
			pickle.dump(self.__default(),self.archivo)
			self.archivo.close()
			self.archivo=open("./drizaconfig","r")
		self.parametros=pickle.load(self.archivo)
		self.archivo.close()
	#Candidata a irse al fichero de listas
	def __default(self):
		listaficheros=datos.Listaficheros(5)
		return {"tmpdir":"/tmp","rdir":"/usr/bin/R","lfichero":listaficheros,"vsplash":True}

	def __getitem__(self,valor):
		return self.parametros[valor]
	def __setitem__(self, clave, valor):
		"""Funcion para establecer la clave de un valor
		"""
		if not clave in self.parametros:
			self.parametros.append(clave)
		self.parametros[clave]=valor
	def save(self):
		self.archivo=open("./drizaconfig","w")
		pickle.dump(self.parametros,self.archivo)
		self.archivo.close()
